==> hermes-2.5.1.75.tar.gz: hermes-2.5.1.75/lib/hermes/bo_client/tasks/add_offer_task.rb <==
# frozen_string_literal: true

# exemple d'utilisation
# id d'offres "valides" transmises par michael
# <<<<<<< HEAD
# 5df10b4a22ec796f8c8f7f82
# 5df10b5722ec796f8c8f7f95
# 5df10b5722ec796fa6995138
# 5df10b5922ec796f8c8f7fa0
# 5df10b5a22ec796fa6995143
# 5df10b5f22ec796f8c8f7fcb
# 5df10b6122ec796f8c8f7fce
# 5df10b61dfbd9710a25de741
# 5df10b63dfbd9710a25de744
# 5df10b6322ec796fa6995166
# 5df10b65dfbd9710886de573
#
#
# ho = Hermes::HousingOffer.find("5eb11bbc3db59f085c5740c9")
#
# so=Hermes::BoClient::AddOfferTask.new({:'housing_offer_id'=> ho.id})
# ExecuteSopraTaskJob.perform_now(so.endpoint, so.to_xml)

=begin
hos = Hermes::HousingOffer.where(last_send_has_error: true)
ap hos.length
hos.each_with_index do |ho,i|
  ho.save
  so=Hermes::BoClient::AddOfferTask.new({:'housing_offer_id'=> ho.id})
 ap  ExecuteSopraTaskJob.perform_now(so.endpoint, so.to_xml, 'post','Hermes::HousingOffer', ho.id.to_s)
  ap i
ap ho.id
end
=end
module Hermes
  module BoClient
    class AddOfferTask < BaseTask
      def initialize(options = {})
        @xsd = 'FluxPatrimoine.xsd'
        super(options)
      end
      endpoint { '/ws/rest/als/bien/v1/integrer' }

      task_name 'addoffer'
      type_flux 'BIEN'
      mapping 'Hermes::BoClient::Mappings::HousingOfferMap'

      params :SIREN_bailleur,
             :libelle_organisme,
             :SIREN_ALS,
             :reference_offre,
             :date_MAD_ALS,
             :date_fin_designation,
             :orientation_bailleur,
             :reference,
             :id_rpls,
             :texte,
             :adresse,
             :adresse_complement,
             :communiquer_adresse_exacte,
             :code_postal,
             :departement,
             :ville,
             :code_residence,
             :libelle_residence,
             :latitude,
             :longitude,
             :QPV,
             :type_construction,
             :nature,
             :type,
             :surface,
             :dpe_etiquette_ges,
             :dpe_etiquette_conso,
             :plafond_ressources,
             :zone_plafond_ressources,
             :nb_pieces_logement,
             :deja_loue,
             :annee_construction,
             :etage,
             :nb_etage,
             :ascenseur,
             :type_chauffage,
             :eau_chaude_distribution,
             :acces_handicapes,
             :copropriete,
             :nature_stationnement,
             :visite_virtuelle,
             :nbr_salle_bain,
             :duplex,
             :balcon_terrasse,
             :jardin,
             :espace_vert,
             :cave,
             :type_cuisine,
             :presence_gardien,
             :loyer_mensuel,
             :charges_locatives,
             :loyer_mensuel_cc,
             :depot_garantie,
             :loyer_stationnement_cc,
             :meuble,
             :positionnement_quartile_1,
             :positionnement_quartiles_autres,
             :public_prioritaire,
             :ref_convention_reservation,
             :raison_sociale_reservataire,
             :SIREN_reservataire,
             :date_disponibilite,
             :id_externe_pdv,
             :libelle_agence,
             :contact_a_afficher,
             :email_a_afficher,
             :telephone_a_afficher
      # photos
    end
  end
end

==> hermes-5.4.0.6.tar.gz: hermes-5.4.0.6/lib/hermes/bo_client/tasks/add_offer_task.rb <==
# frozen_string_literal: true

# exemple d'utilisation
# id d'offres "valides" transmises par michael
# <<<<<<< HEAD
# 5df10b4a22ec796f8c8f7f82
# 5df10b5722ec796f8c8f7f95
# 5df10b5722ec796fa6995138
# 5df10b5922ec796f8c8f7fa0
# 5df10b5a22ec796fa6995143
# 5df10b5f22ec796f8c8f7fcb
# 5df10b6122ec796f8c8f7fce
# 5df10b61dfbd9710a25de741
# 5df10b63dfbd9710a25de744
# 5df10b6322ec796fa6995166
# 5df10b65dfbd9710886de573
#
#
# ho = Hermes::HousingOffer.find("5eb11bbc3db59f085c5740c9")
#
# so=Hermes::BoClient::AddOfferTask.new({:'housing_offer_id'=> ho.id})
# ExecuteSopraTaskJob.perform_now(so.endpoint, so.to_xml)

=begin
hos = Hermes::HousingOffer.where(last_send_has_error: true)
ap hos.length
hos.each_with_index do |ho,i|
  ho.save
  so=Hermes::BoClient::AddOfferTask.new({:'housing_offer_id'=> ho.id})
 ap  ExecuteSopraTaskJob.perform_now(so.endpoint, so.to_xml, 'post','Hermes::HousingOffer', ho.id.to_s)
  ap i
ap ho.id
end
=end
module Hermes
  module BoClient
    class AddOfferTask < BaseTask
      def initialize(options = {})
        @xsd = 'FluxPatrimoine.xsd'
        super(options)
      end
      endpoint { '/ws/rest/als/bien/v1/integrer' }

      task_name 'addoffer'
      type_flux 'BIEN'
      mapping 'Hermes::BoClient::Mappings::HousingOfferMap'

      params :SIREN_bailleur,
             :libelle_organisme,
             :code_territoire,
             :SIREN_ALS,
             :reference_offre,
             :date_MAD_ALS,
             :date_fin_designation,
             #:orientation_bailleur,
             :reference,
             :id_rpls,
             :texte,
             :adresse,
             :adresse_complement,
             :communiquer_adresse_exacte,
             :code_postal,
             :departement,
             :ville,
             :code_residence,
             :libelle_residence,
             :latitude,
             :longitude,
             :QPV,
             :type_construction,
             :nature,
             :type,
             :surface,
             :dpe_etiquette_ges,
             :dpe_etiquette_conso,
             :plafond_ressources,
             :zone_plafond_ressources,
             :nb_pieces_logement,
             :deja_loue,
             :annee_construction,
             :etage,
             :nb_etage,
             :ascenseur,
             :type_chauffage,
             :eau_chaude_distribution,
             :acces_handicapes,
             :copropriete,
             :nature_stationnement,
             :visite_virtuelle,
             :nbr_salle_bain,
             :duplex,
             :balcon_terrasse,
             :jardin,
             :espace_vert,
             :cave,
             :type_cuisine,
             :presence_gardien,
             :loyer_mensuel,
             :charges_locatives,
             :loyer_mensuel_cc,
             :depot_garantie,
             :loyer_stationnement_cc,
             :meuble,
             :positionnement_quartile_1,
             :positionnement_quartiles_autres,
             :public_prioritaire,
             :ref_convention_reservation,
             :raison_sociale_reservataire,
             :SIREN_reservataire,
             :date_disponibilite,
             :id_externe_pdv,
             :libelle_agence,
             :contact_a_afficher,
             :email_a_afficher,
             :telephone_a_afficher
      # photos
    end
  end
end
